@@ -7,8 +7,8 @@
 #include "exrcreator.h"
 #include "thumbnail-exr-logsettings.h"
 
-#include <QImage>
 #include <QFile>
+#include <QImage>
 
 #include <ImfHeader.h>
 #include <ImfInputFile.h>
@@ -31,16 +31,16 @@ KIO::ThumbnailResult EXRCreator::create(const KIO::ThumbnailRequest &request)
 {
     try {
         const QByteArray encodedPath = QFile::encodeName(request.url().toLocalFile());
-        Imf::InputFile in (encodedPath.constData());
+        Imf::InputFile in(encodedPath.constData());
         const Imf::Header &h = in.header();
-        if ( h.hasPreviewImage() ) {
+        if (h.hasPreviewImage()) {
             qCDebug(KIO_THUMBNAIL_EXR_LOG) << "EXRcreator - using preview";
             const Imf::PreviewImage &preview = h.previewImage();
             QImage qpreview(preview.width(), preview.height(), QImage::Format_RGB32);
-            for ( unsigned int y=0; y < preview.height(); y++ ) {
-                for ( unsigned int x=0; x < preview.width(); x++ ) {
-                    const Imf::PreviewRgba &q = preview.pixels()[x+(y*preview.width())];
-                    qpreview.setPixel( x, y, qRgba(q.r, q.g, q.b, q.a) );
+            for (unsigned int y = 0; y < preview.height(); y++) {
+                for (unsigned int x = 0; x < preview.width(); x++) {
+                    const Imf::PreviewRgba &q = preview.pixels()[x + (y * preview.width())];
+                    qpreview.setPixel(x, y, qRgba(q.r, q.g, q.b, q.a));
                 }
             }
             return KIO::ThumbnailResult::pass(qpreview);
@@ -57,17 +57,14 @@ KIO::ThumbnailResult EXRCreator::create(const KIO::ThumbnailRequest &request)
     // to honoring it in here.
     qCDebug(KIO_THUMBNAIL_EXR_LOG) << "EXRcreator - using original image";
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup configGroup( config, "PreviewSettings" );
-    const qint64 maxSize = configGroup.readEntry( "MaximumSize", std::numeric_limits<qint64>::max() );
+    KConfigGroup configGroup(config, "PreviewSettings");
+    const qint64 maxSize = configGroup.readEntry("MaximumSize", std::numeric_limits<qint64>::max());
     const qint64 fileSize = QFile(request.url().toLocalFile()).size();
-    if ( (fileSize > 0) && (fileSize < maxSize) ) {
+    if ((fileSize > 0) && (fileSize < maxSize)) {
         QImage img;
         if (!img.load(request.url().toLocalFile())) {
             return KIO::ThumbnailResult::fail();
         }
-        if (img.depth() != 32) {
-            img = img.convertToFormat( QImage::Format_RGB32 );
-        }
         return KIO::ThumbnailResult::pass(img);
     } else {
         return KIO::ThumbnailResult::fail();
